# 🧣 Bookshelf Spline

This datapack allows you to easily manipulate smooth curves created from control points.

> “Do not go where the path may lead, go instead where there is no path and leave a trail.”
>
> -- Ralph Waldo Emerson

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/spline.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
